@@ -1,10 +1,10 @@
-/* $Cambridge: exim/exim-src/exim_monitor/em_globals.c,v 1.9 2006/02/07 11:18:59 ph10 Exp $ */
+/* $Cambridge: exim/exim-src/exim_monitor/em_globals.c,v 1.12 2007/06/22 14:38:58 ph10 Exp $ */
 
 /*************************************************
 *                Exim Monitor                    *
 *************************************************/
 
-/* Copyright (c) University of Cambridge 1995 - 2006 */
+/* Copyright (c) University of Cambridge 1995 - 2007 */
 /* See the file NOTICE for conditions of use and distribution. */
 
 
@@ -117,9 +117,8 @@ that fires up the monitor fishes the value out by using -bP anyway. */
 #define SPOOL_DIRECTORY ""
 #endif
 
-
-uschar *acl_var[ACL_CVARS + ACL_MVARS];
-
+tree_node *acl_var_c           = NULL;
+tree_node *acl_var_m           = NULL;
 uschar *active_hostname        = NULL;
 BOOL    allow_unqualified_recipient = FALSE;
 BOOL    allow_unqualified_sender = FALSE;
@@ -164,6 +163,7 @@ BOOL    log_timezone           = FALSE;
 uschar *spam_score_int         = NULL;
 #endif
 
+int     max_received_linelength= 0;
 int     message_age            = 0;
 uschar *message_id;
 uschar *message_id_external;
