@@ -1,10 +1,10 @@
-/* $Cambridge: exim/exim-src/src/local_scan.h,v 1.7 2006/02/14 10:26:27 ph10 Exp $ */
+/* $Cambridge: exim/exim-src/src/local_scan.h,v 1.11 2007/06/14 13:27:11 ph10 Exp $ */
 
 /*************************************************
 *     Exim - an Internet mail transport agent    *
 *************************************************/
 
-/* Copyright (c) University of Cambridge 1995 - 2006 */
+/* Copyright (c) University of Cambridge 1995 - 2007 */
 /* See the file NOTICE for conditions of use and distribution. */
 
 /* This file is the header that is the only Exim header to be included in the
@@ -100,7 +100,9 @@ each time a new feature is added (in a way that doesn't break backward
 compatibility). */
 
 #define LOCAL_SCAN_ABI_VERSION_MAJOR 1
-#define LOCAL_SCAN_ABI_VERSION_MINOR 0
+#define LOCAL_SCAN_ABI_VERSION_MINOR 1
+#define LOCAL_SCAN_ABI_VERSION \
+  LOCAL_SCAN_ABI_VERSION_MAJOR.LOCAL_SCAN_ABI_VERSION_MINOR
 
 /* Structure definitions that are documented as visible in the function. */
 
@@ -137,6 +139,8 @@ typedef struct recipient_item {
 
 extern unsigned int debug_selector;    /* Debugging bits */
 
+extern int     body_linecount;         /* Line count in body */
+extern int     body_zerocount;         /* Binary zero count in body */
 extern uschar *expand_string_message;  /* Error info for failing expansion */
 extern uschar *headers_charset;        /* Charset for RFC 2047 decoding */
 extern header_line *header_last;       /* Final header */
