@@ -1,4 +1,4 @@
-/* $Cambridge: exim/exim-src/src/lookups/lf_functions.h,v 1.4 2007/01/08 10:50:19 ph10 Exp $ */
+/* $Cambridge: exim/exim-src/src/lookups/lf_functions.h,v 1.5 2007/08/23 10:16:51 ph10 Exp $ */
 
 /*************************************************
 *     Exim - an Internet mail transport agent    *
@@ -12,5 +12,8 @@
 extern int     lf_check_file(int, uschar *, int, int, uid_t *, gid_t *, char *,
                  uschar **);
 extern uschar *lf_quote(uschar *, uschar *, int, uschar *, int *, int *);
+extern int     lf_sqlperform(uschar *, uschar *, uschar *, uschar *, uschar **,
+                 uschar **, BOOL *, int(*)(uschar *, uschar *, uschar **,
+                 uschar **, BOOL *, BOOL *));
 
 /* End of lf_functions.h */
