@@ -1,10 +1,10 @@
-/* $Cambridge: exim/exim-src/src/lookups/pgsql.c,v 1.7 2006/07/14 14:42:57 ph10 Exp $ */
+/* $Cambridge: exim/exim-src/src/lookups/pgsql.c,v 1.10 2007/08/23 10:16:51 ph10 Exp $ */
 
 /*************************************************
 *     Exim - an Internet mail transport agent    *
 *************************************************/
 
-/* Copyright (c) University of Cambridge 1995 - 2006 */
+/* Copyright (c) University of Cambridge 1995 - 2007 */
 /* See the file NOTICE for conditions of use and distribution. */
 
 /* Thanks to Petr Cech for contributing the original code for these
@@ -128,7 +128,7 @@ Arguments:
   server       the server string; this is in dynamic memory and can be updated
   resultptr    where to store the result
   errmsg       where to point an error message
-  defer_break  TRUE if no more servers are to be tried after DEFER
+  defer_break  set TRUE if no more servers are to be tried after DEFER
   do_cache     set FALSE if data is changed
 
 Returns:       OK, FAIL, or DEFER
@@ -265,7 +265,6 @@ if (cn == NULL)
     *errmsg = string_sprintf("PGSQL connection failed: %s",
       PQerrorMessage(pg_conn));
     PQfinish(pg_conn);
-    *defer_break = FALSE;
     goto PGSQL_EXIT;
     }
 
@@ -328,7 +327,6 @@ else
     *errmsg = string_sprintf("PGSQL: query failed: %s (%s) (%s)\n",
                              PQresultErrorMessage(pg_result),
                              PQresStatus(PQresultStatus(pg_result)), query);
-    *defer_break = FALSE;
     goto PGSQL_EXIT;
     }
 
@@ -412,33 +410,16 @@ else
 *************************************************/
 
 /* See local README for interface description. The handle and filename
-arguments are not used. Loop through a list of servers while the query is
-deferred with a retryable error. */
+arguments are not used. The code to loop through a list of servers while the
+query is deferred with a retryable error is now in a separate function that is
+shared with other SQL lookups. */
 
 int
 pgsql_find(void *handle, uschar *filename, uschar *query, int length,
   uschar **result, uschar **errmsg, BOOL *do_cache)
 {
-int sep = 0;
-uschar *server;
-uschar *list = pgsql_servers;
-uschar buffer[512];
-
-DEBUG(D_lookup) debug_printf("PGSQL query: %s\n", query);
-
-while ((server = string_nextinlist(&list, &sep, buffer, sizeof(buffer)))
-        != NULL)
-  {
-  BOOL defer_break;
-  int rc = perform_pgsql_search(query, server, result, errmsg, &defer_break,
-    do_cache);
-  if (rc != DEFER || defer_break) return rc;
-  }
-
-if (pgsql_servers == NULL)
-  *errmsg = US"no PGSQL servers defined (pgsql_servers option)";
-
-return DEFER;
+return lf_sqlperform(US"PostgreSQL", US"pgsql_servers", pgsql_servers, query,
+  result, errmsg, do_cache, perform_pgsql_search);
 }
 
 
