@@ -1,10 +1,10 @@
-/* $Cambridge: exim/exim-src/src/rda.c,v 1.12 2006/02/07 11:19:00 ph10 Exp $ */
+/* $Cambridge: exim/exim-src/src/rda.c,v 1.14 2007/01/08 10:50:18 ph10 Exp $ */
 
 /*************************************************
 *     Exim - an Internet mail transport agent    *
 *************************************************/
 
-/* Copyright (c) University of Cambridge 1995 - 2006 */
+/* Copyright (c) University of Cambridge 1995 - 2007 */
 /* See the file NOTICE for conditions of use and distribution. */
 
 /* This module contains code for extracting addresses from a forwarding list
@@ -352,7 +352,7 @@ uschar *data;
 
 if (rdata->isfile)
   {
-  int yield;
+  int yield = 0;
   data = rda_get_file_contents(rdata, options, error, &yield);
   if (data == NULL) return yield;
   }
