@@ -1,10 +1,10 @@
-/* $Cambridge: exim/exim-src/src/routers/manualroute.h,v 1.4 2006/02/07 11:19:02 ph10 Exp $ */
+/* $Cambridge: exim/exim-src/src/routers/manualroute.h,v 1.6 2007/03/13 15:32:48 ph10 Exp $ */
 
 /*************************************************
 *     Exim - an Internet mail transport agent    *
 *************************************************/
 
-/* Copyright (c) University of Cambridge 1995 - 2006 */
+/* Copyright (c) University of Cambridge 1995 - 2007 */
 /* See the file NOTICE for conditions of use and distribution. */
 
 /* Header for the manualroute router */
@@ -12,8 +12,10 @@
 /* Structure for the private options. */
 
 typedef struct {
+  int   hai_code;
   int   hff_code;
   BOOL  hosts_randomize;
+  uschar *host_all_ignored;
   uschar *host_find_failed;
   uschar *route_data;
   uschar *route_list;
