@@ -1,10 +1,10 @@
-/* $Cambridge: exim/exim-src/src/sieve.c,v 1.21 2006/04/25 10:44:57 ph10 Exp $ */
+/* $Cambridge: exim/exim-src/src/sieve.c,v 1.32 2007/10/11 12:44:30 michael Exp $ */
 
 /*************************************************
 *     Exim - an Internet mail transport agent    *
 *************************************************/
 
-/* Copyright (c) Michael Haardt 2003-2006 */
+/* Copyright (c) Michael Haardt 2003-2007 */
 /* See the file NOTICE for conditions of use and distribution. */
 
 /* This code was contributed by Michael Haardt. */
@@ -28,11 +28,14 @@
 /* Undefine it for UNIX-style \n end-of-line terminators (default). */
 #undef RFC_EOL
 
+/* Define this for development of the Sieve extension "encoded-character". */
+#define ENCODED_CHARACTER
+
 /* Define this for development of the Sieve extension "envelope-auth". */
 #undef ENVELOPE_AUTH
 
-/* Define this for development of the Sieve extension "notify".     */
-#undef NOTIFY
+/* Define this for development of the Sieve extension "enotify".    */
+#define ENOTIFY
 
 /* Define this for the Sieve extension "subaddress".                */
 #define SUBADDRESS
@@ -58,11 +61,14 @@ struct Sieve
   int keep;
   int require_envelope;
   int require_fileinto;
+#ifdef ENCODED_CHARACTER
+  int require_encoded_character;
+#endif
 #ifdef ENVELOPE_AUTH
   int require_envelope_auth;
 #endif
-#ifdef NOTIFY
-  int require_notify;
+#ifdef ENOTIFY
+  int require_enotify;
   struct Notification *notified;
 #endif
 #ifdef SUBADDRESS
@@ -97,11 +103,12 @@ struct String
 struct Notification
   {
   struct String method;
-  struct String priority;
+  struct String importance;
   struct String message;
   struct Notification *next;
   };
 
+static int eq_asciicase(const struct String *needle, const struct String *haystack, int match_prefix);
 static int parse_test(struct Sieve *filter, int *cond, int exec);
 static int parse_commands(struct Sieve *filter, int exec, address_item **generated);
 
@@ -125,13 +132,23 @@ static uschar str_fileinto_c[]="fileinto";
 static const struct String str_fileinto={ str_fileinto_c, 8 };
 static uschar str_envelope_c[]="envelope";
 static const struct String str_envelope={ str_envelope_c, 8 };
+#ifdef ENCODED_CHARACTER
+static uschar str_encoded_character_c[]="encoded-character";
+static const struct String str_encoded_character={ str_encoded_character_c, 17 };
+#endif
 #ifdef ENVELOPE_AUTH
 static uschar str_envelope_auth_c[]="envelope-auth";
 static const struct String str_envelope_auth={ str_envelope_auth_c, 13 };
 #endif
-#ifdef NOTIFY
-static uschar str_notify_c[]="notify";
-static const struct String str_notify={ str_notify_c, 6 };
+#ifdef ENOTIFY
+static uschar str_enotify_c[]="enotify";
+static const struct String str_enotify={ str_enotify_c, 7 };
+static uschar str_online_c[]="online";
+static const struct String str_online={ str_online_c, 6 };
+static uschar str_maybe_c[]="maybe";
+static const struct String str_maybe={ str_maybe_c, 5 };
+static uschar str_auto_submitted_c[]="Auto-Submitted";
+static const struct String str_auto_submitted={ str_auto_submitted_c, 14 };
 #endif
 #ifdef SUBADDRESS
 static uschar str_subaddress_c[]="subaddress";
@@ -256,6 +273,48 @@ for (pass=0; pass<=1; ++pass)
 }
 
 
+/*************************************************
+*     Check mail address for correct syntax      *
+*************************************************/
+
+/*
+Check mail address for being syntactically correct.
+
+Arguments:
+  filter      points to the Sieve filter including its state
+  address     String containing one address
+
+Returns
+  1           Mail address is syntactically OK
+ -1           syntax error
+*/
+
+int check_mail_address(struct Sieve *filter, const struct String *address)
+{
+int start, end, domain;
+uschar *error,*ss;
+
+if (address->length>0)
+  {
+  ss = parse_extract_address(address->character, &error, &start, &end, &domain,
+    FALSE);
+  if (ss == NULL)
+    {
+    filter->errmsg=string_sprintf("malformed address \"%s\" (%s)",
+      address->character, error);
+    return -1;
+    }
+  else
+    return 1;
+  }
+else
+  {
+  filter->errmsg=CUS "empty address";
+  return -1;
+  }
+}
+
+
 /*************************************************
 *          Decode URI encoded string             *
 *************************************************/
@@ -269,6 +328,7 @@ Returns
  -1                 Encoding error
 */
 
+#ifdef ENOTIFY
 static int uri_decode(struct String *str)
 {
 uschar *s,*t,*e;
@@ -312,19 +372,28 @@ Parse mailto-URI.
 Arguments:
   filter      points to the Sieve filter including its state
   uri         URI, excluding scheme
+  recipient
+  body
 
 Returns
   1           URI is syntactically OK
+  0           Unknown URI scheme
  -1           syntax error
 */
 
-int parse_mailto_uri(struct Sieve *filter, const uschar *uri, string_item **recipient, struct String *body)
+static int parse_mailto_uri(struct Sieve *filter, const uschar *uri, string_item **recipient, struct String *header, struct String *subject, struct String *body)
 {
 const uschar *start;
 struct String to,hname,hvalue;
 int capacity;
 string_item *new;
 
+if (Ustrncmp(uri,"mailto:",7))
+  {
+  filter->errmsg=US "Unknown URI scheme";
+  return 0;
+  }
+uri+=7;
 if (*uri && *uri!='?')
   for (;;)
     {
@@ -400,7 +469,7 @@ if (*uri=='?')
         return -1;
         }
       }
-    if (hname.length==2 && strcmp(CS hname.character,"to")==0)
+    if (hname.length==2 && strcmpic(hname.character, US"to")==0)
       {
       new=store_get(sizeof(string_item));
       new->text=store_get(hvalue.length+1);
@@ -409,8 +478,35 @@ if (*uri=='?')
       new->next=*recipient;
       *recipient=new;
       }
-    else if (hname.length==4 && strcmp(CS hname.character,"body")==0)
+    else if (hname.length==4 && strcmpic(hname.character, US"body")==0)
       *body=hvalue;
+    else if (hname.length==7 && strcmpic(hname.character, US"subject")==0)
+      *subject=hvalue;
+    else
+      {
+      static struct String ignore[]=
+        {
+        {US"date",4},
+        {US"from",4},
+        {US"message-id",10},
+        {US"received",8},
+        {US"auto-submitted",14}
+        };
+      static struct String *end=ignore+sizeof(ignore)/sizeof(ignore[0]);
+      struct String *i;
+
+      for (i=ignore; i<end && !eq_asciicase(&hname,i,0); ++i);
+      if (i==end)
+        {
+        if (header->length==-1) header->length=0;
+        capacity=header->length;
+        header->character=string_cat(header->character,&capacity,&header->length,hname.character,hname.length);
+        header->character=string_cat(header->character,&capacity,&header->length,CUS ": ",2);
+        header->character=string_cat(header->character,&capacity,&header->length,hvalue.character,hvalue.length);
+        header->character=string_cat(header->character,&capacity,&header->length,CUS "\n",1);
+        header->character[header->length]='\0';
+        }
+      }
     if (*uri=='&') ++uri;
     else break;
     }
@@ -422,6 +518,8 @@ if (*uri)
   }
 return 1;
 }
+#endif
+
 
 /*************************************************
 *          Octet-wise string comparison          *
@@ -1107,8 +1205,212 @@ return 1;
 }
 
 
+#ifdef ENCODED_CHARACTER
 /*************************************************
-*          Parse a optional string               *
+*      Decode hex-encoded-character string       *
+*************************************************/
+
+/*
+Encoding definition:
+   blank                = SP / TAB / CRLF
+   hex-pair-seq         = *blank hex-pair *(1*blank hex-pair) *blank
+   hex-pair             = 1*2HEXDIG
+
+Arguments:
+  src         points to a hex-pair-seq
+  end         points to its end
+  dst         points to the destination of the decoded octets,
+              optionally to (uschar*)0 for checking only
+
+Returns:      >=0              number of decoded octets
+              -1               syntax error
+*/
+
+static int hex_decode(uschar *src, uschar *end, uschar *dst)
+{
+int decoded=0;
+
+while (*src==' ' || *src=='\t' || *src=='\n') ++src;
+do
+  {
+  int x,d,n;
+
+  for (x=0,d=0; d<2 && src<end && isxdigit(n=tolower(*src)); x=(x<<4)|(n>='0' && n<='9' ? n-'0' : 10+(n-'a')),++d,++src);
+  if (d==0) return -1;
+  if (dst) *dst++=x;
+  ++decoded;
+  if (src==end) return decoded;
+  if (*src==' ' || *src=='\t' || *src=='\n')
+    while (*src==' ' || *src=='\t' || *src=='\n') ++src;
+  else
+    return -1;
+  }
+while (src<end);
+return decoded;
+}
+
+
+/*************************************************
+*    Decode unicode-encoded-character string     *
+*************************************************/
+
+/*
+Encoding definition:
+   blank                = SP / TAB / CRLF
+   unicode-hex-seq      = *blank unicode-hex *(blank unicode-hex) *blank
+   unicode-hex          = 1*HEXDIG
+
+   It is an error for a script to use a hexadecimal value that isn't in
+   either the range 0 to D7FF or the range E000 to 10FFFF.
+
+   At this time, strings are already scanned, thus the CRLF is converted
+   to the internally used \n (should RFC_EOL have been used).
+
+Arguments:
+  src         points to a unicode-hex-seq
+  end         points to its end
+  dst         points to the destination of the decoded octets,
+              optionally to (uschar*)0 for checking only
+
+Returns:      >=0              number of decoded octets
+              -1               syntax error
+              -2               semantic error (character range violation)
+*/
+
+static int unicode_decode(uschar *src, uschar *end, uschar *dst)
+{
+int decoded=0;
+
+while (*src==' ' || *src=='\t' || *src=='\n') ++src;
+do
+  {
+  uschar *hex_seq;
+  int c,d,n;
+
+  unicode_hex:
+  for (hex_seq=src; src<end && *src=='0'; ++src);
+  for (c=0,d=0; d<7 && src<end && isxdigit(n=tolower(*src)); c=(c<<4)|(n>='0' && n<='9' ? n-'0' : 10+(n-'a')),++d,++src);
+  if (src==hex_seq) return -1;
+  if (d==7 || (!((c>=0 && c<=0xd7ff) || (c>=0xe000 && c<=0x10ffff)))) return -2;
+  if (c<128)
+    {
+    if (dst) *dst++=c;
+    ++decoded;
+    }
+  else if (c>=0x80 && c<=0x7ff)
+    {
+      if (dst)
+        {
+        *dst++=192+(c>>6);
+        *dst++=128+(c&0x3f);
+        }
+      decoded+=2;
+    }
+  else if (c>=0x800 && c<=0xffff)
+    {
+      if (dst)
+        {
+        *dst++=224+(c>>12);
+        *dst++=128+((c>>6)&0x3f);
+        *dst++=128+(c&0x3f);
+        }
+      decoded+=3;
+    }
+  else if (c>=0x10000 && c<=0x1fffff)
+    {
+      if (dst)
+        {
+        *dst++=240+(c>>18);
+        *dst++=128+((c>>10)&0x3f);
+        *dst++=128+((c>>6)&0x3f);
+        *dst++=128+(c&0x3f);
+        }
+      decoded+=4;
+    }
+  if (*src==' ' || *src=='\t' || *src=='\n')
+    {
+    while (*src==' ' || *src=='\t' || *src=='\n') ++src;
+    if (src==end) return decoded;
+    goto unicode_hex;
+    }
+  }
+while (src<end);
+return decoded;
+}
+
+
+/*************************************************
+*       Decode encoded-character string          *
+*************************************************/
+
+/*
+Encoding definition:
+   encoded-arb-octets   = "${hex:" hex-pair-seq "}"
+   encoded-unicode-char = "${unicode:" unicode-hex-seq "}"
+
+Arguments:
+  encoded     points to an encoded string, returns decoded string
+  filter      points to the Sieve filter including its state
+
+Returns:      1                success
+              -1               syntax error
+*/
+
+static int string_decode(struct Sieve *filter, struct String *data)
+{
+uschar *src,*dst,*end;
+
+src=data->character;
+dst=src;
+end=data->character+data->length;
+while (src<end)
+  {
+  uschar *brace;
+
+  if (
+      strncmpic(src,US "${hex:",6)==0
+      && (brace=Ustrchr(src+6,'}'))!=(uschar*)0
+      && (hex_decode(src+6,brace,(uschar*)0))>=0
+     )
+    {
+    dst+=hex_decode(src+6,brace,dst);
+    src=brace+1;
+    }
+  else if (
+           strncmpic(src,US "${unicode:",10)==0
+           && (brace=Ustrchr(src+10,'}'))!=(uschar*)0
+          )
+    {
+    switch (unicode_decode(src+10,brace,(uschar*)0))
+      {
+      case -2:
+        {
+        filter->errmsg=CUS "unicode character out of range";
+        return -1;
+        }
+      case -1:
+        {
+        *dst++=*src++;
+        break;
+        }
+      default:
+        {
+        dst+=unicode_decode(src+10,brace,dst);
+        src=brace+1;
+        }
+      }
+    }
+  else *dst++=*src++;
+  }
+  data->length=dst-data->character;
+  *dst='\0';
+return 1;
+}
+#endif
+
+
+/*************************************************
+*          Parse an optional string              *
 *************************************************/
 
 /*
@@ -1155,12 +1457,16 @@ if (*filter->pc=='"') /* quoted string */
       ++filter->pc;
       /* that way, there will be at least one character allocated */
       data->character=string_cat(data->character,&dataCapacity,&foo,CUS "",1);
+#ifdef ENCODED_CHARACTER
+      if (filter->require_encoded_character
+          && string_decode(filter,data)==-1)
+        return -1;
+#endif
       return 1;
       }
     else if (*filter->pc=='\\' && *(filter->pc+1)) /* quoted character */
       {
-      if (*(filter->pc+1)=='0') data->character=string_cat(data->character,&dataCapacity,&data->length,CUS "",1);
-      else data->character=string_cat(data->character,&dataCapacity,&data->length,filter->pc+1,1);
+      data->character=string_cat(data->character,&dataCapacity,&data->length,filter->pc+1,1);
       filter->pc+=2;
       }
     else /* regular character */
@@ -1239,6 +1545,11 @@ else if (Ustrncmp(filter->pc,CUS "text:",5)==0) /* multiline string */
         filter->pc+=2;
 #endif
         ++filter->line;
+#ifdef ENCODED_CHARACTER
+        if (filter->require_encoded_character
+            && string_decode(filter,data)==-1)
+          return -1;
+#endif
         return 1;
         }
       else if (*filter->pc=='.' && *(filter->pc+1)=='.') /* remove dot stuffing */
@@ -1280,7 +1591,7 @@ static int parse_identifier(struct Sieve *filter, const uschar *id)
 {
   size_t idlen=Ustrlen(id);
 
-  if (Ustrncmp(filter->pc,id,idlen)==0)
+  if (strncmpic(US filter->pc,US id,idlen)==0)
   {
     uschar next=filter->pc[idlen];
 
@@ -1634,14 +1945,14 @@ Returns:      1                success
               -1               syntax or execution error
 */
 
-static int parse_testlist(struct Sieve *filter, int *n, int *true, int exec)
+static int parse_testlist(struct Sieve *filter, int *n, int *num_true, int exec)
 {
 if (parse_white(filter)==-1) return -1;
 if (*filter->pc=='(')
   {
   ++filter->pc;
   *n=0;
-   *true=0;
+   *num_true=0;
   for (;;)
     {
     int cond;
@@ -1650,7 +1961,7 @@ if (*filter->pc=='(')
       {
       case -1: return -1;
       case 0: filter->errmsg=CUS "missing test"; return -1;
-      default: ++*n; if (cond) ++*true; break;
+      default: ++*n; if (cond) ++*num_true; break;
       }
     if (parse_white(filter)==-1) return -1;
     if (*filter->pc==',') ++filter->pc;
@@ -1826,6 +2137,8 @@ if (parse_identifier(filter,CUS "address"))
         if (saveend == 0) break;
         header_value = end_addr + 1;
         }
+      parse_allow_group = FALSE;
+      parse_found_group = FALSE;
       }
     }
   return 1;
@@ -1836,13 +2149,13 @@ else if (parse_identifier(filter,CUS "allof"))
   allof-test   = "allof" <tests: test-list>
   */
 
-  int n,true;
+  int n,num_true;
 
-  switch (parse_testlist(filter,&n,&true,exec))
+  switch (parse_testlist(filter,&n,&num_true,exec))
     {
     case -1: return -1;
     case 0: filter->errmsg=CUS "missing test list"; return -1;
-    default: *cond=(n==true); return 1;
+    default: *cond=(n==num_true); return 1;
     }
   }
 else if (parse_identifier(filter,CUS "anyof"))
@@ -1851,13 +2164,13 @@ else if (parse_identifier(filter,CUS "anyof"))
   anyof-test   = "anyof" <tests: test-list>
   */
 
-  int n,true;
+  int n,num_true;
 
-  switch (parse_testlist(filter,&n,&true,exec))
+  switch (parse_testlist(filter,&n,&num_true,exec))
     {
     case -1: return -1;
     case 0: filter->errmsg=CUS "missing test list"; return -1;
-    default: *cond=(true>0); return 1;
+    default: *cond=(num_true>0); return 1;
     }
   }
 else if (parse_identifier(filter,CUS "exists"))
@@ -2171,6 +2484,139 @@ else if (parse_identifier(filter,CUS "envelope"))
     }
   return 1;
   }
+#ifdef ENOTIFY
+else if (parse_identifier(filter,CUS "valid_notify_method"))
+  {
+  /*
+  valid_notify_method = "valid_notify_method"
+                        <notification-uris: string-list>
+  */
+
+  struct String *uris,*u;
+  int m;
+
+  if (!filter->require_enotify)
+    {
+    filter->errmsg=CUS "missing previous require \"enotify\";";
+    return -1;
+    }
+  if (parse_white(filter)==-1) return -1;
+  if ((m=parse_stringlist(filter,&uris))!=1)
+    {
+    if (m==0) filter->errmsg=CUS "URI string list expected";
+    return -1;
+    }
+  if (exec)
+    {
+    *cond=1;
+    for (u=uris; u->length!=-1 && *cond; ++u)
+      {
+        string_item *recipient;
+        struct String header,subject,body;
+
+        recipient=NULL;
+        header.length=-1;
+        header.character=(uschar*)0;
+        subject.length=-1;
+        subject.character=(uschar*)0;
+        body.length=-1;
+        body.character=(uschar*)0;
+        if (parse_mailto_uri(filter,u->character,&recipient,&header,&subject,&body)!=1)
+          *cond=0;
+      }
+    }
+  return 1;
+  }
+else if (parse_identifier(filter,CUS "notify_method_capability"))
+  {
+  /*
+  notify_method_capability = "notify_method_capability" [COMPARATOR] [MATCH-TYPE]
+                             <notification-uri: string>
+                             <notification-capability: string>
+                             <key-list: string-list>
+  */
+
+  int m;
+  int co=0,mt=0;
+
+  enum Comparator comparator=COMP_EN_ASCII_CASEMAP;
+  enum MatchType matchType=MATCH_IS;
+  struct String uri,capa,*keys,*k;
+
+  if (!filter->require_enotify)
+    {
+    filter->errmsg=CUS "missing previous require \"enotify\";";
+    return -1;
+    }
+  for (;;)
+    {
+    if (parse_white(filter)==-1) return -1;
+    if ((m=parse_comparator(filter,&comparator))!=0)
+      {
+      if (m==-1) return -1;
+      if (co)
+        {
+        filter->errmsg=CUS "comparator already specified";
+        return -1;
+        }
+      else co=1;
+      }
+    else if ((m=parse_matchtype(filter,&matchType))!=0)
+      {
+      if (m==-1) return -1;
+      if (mt)
+        {
+        filter->errmsg=CUS "match type already specified";
+        return -1;
+        }
+      else mt=1;
+      }
+    else break;
+    }
+    if ((m=parse_string(filter,&uri))!=1)
+      {
+      if (m==0) filter->errmsg=CUS "missing notification URI string";
+      return -1;
+      }
+    if (parse_white(filter)==-1) return -1;
+    if ((m=parse_string(filter,&capa))!=1)
+      {
+      if (m==0) filter->errmsg=CUS "missing notification capability string";
+      return -1;
+      }
+    if (parse_white(filter)==-1) return -1;
+    if ((m=parse_stringlist(filter,&keys))!=1)
+      {
+      if (m==0) filter->errmsg=CUS "missing key string list";
+      return -1;
+      }
+    if (exec)
+      {
+      string_item *recipient;
+      struct String header,subject,body;
+
+      *cond=0;
+      recipient=NULL;
+      header.length=-1;
+      header.character=(uschar*)0;
+      subject.length=-1;
+      subject.character=(uschar*)0;
+      body.length=-1;
+      body.character=(uschar*)0;
+      if (parse_mailto_uri(filter,uri.character,&recipient,&header,&subject,&body)==1)
+        {
+        if (eq_asciicase(&capa,&str_online,0)==1)
+          for (k=keys; k->length!=-1; ++k)
+            {
+            *cond=compare(filter,k,&str_maybe,comparator,matchType);
+            if (*cond==-1) return -1;
+            if (*cond) break;
+            }
+        }
+      }
+    return 1;
+  }
+#endif
 else return 0;
 }
 
@@ -2477,37 +2923,49 @@ while (*filter->pc)
       }
     if (parse_semicolon(filter)==-1) return -1;
     }
-#ifdef NOTIFY
+#ifdef ENOTIFY
   else if (parse_identifier(filter,CUS "notify"))
     {
     /*
-    notify-command =  "notify" { notify-options } ";"
-    notify-options =  [":method" string]
-                      [":priority" string]
+    notify-command =  "notify" { notify-options } <method: string> ";"
+    notify-options =  [":from" string]
+                      [":importance" <"1" / "2" / "3">]
+                      [":options" 1*(string-list / number)]
                       [":message" string]
     */
 
     int m;
-    struct String method;
-    struct String priority;
+    struct String from;
+    struct String importance;
+    struct String *options;
     struct String message;
+    struct String method;
     struct Notification *already;
     string_item *recipient;
+    struct String header;
+    struct String subject;
     struct String body;
     uschar *envelope_from,*envelope_to;
+    struct String auto_submitted_value;
+    uschar *auto_submitted_def;
 
-    if (!filter->require_notify)
+    if (!filter->require_enotify)
       {
-      filter->errmsg=CUS "missing previous require \"notify\";";
+      filter->errmsg=CUS "missing previous require \"enotify\";";
       return -1;
       }
-    method.character=(uschar*)0;
-    method.length=-1;
-    priority.character=(uschar*)0;
-    priority.length=-1;
+    from.character=(uschar*)0;
+    from.length=-1;
+    importance.character=(uschar*)0;
+    importance.length=-1;
+    options=(struct String*)0;
     message.character=(uschar*)0;
     message.length=-1;
     recipient=NULL;
+    header.length=-1;
+    header.character=(uschar*)0;
+    subject.length=-1;
+    subject.character=(uschar*)0;
     body.length=-1;
     body.character=(uschar*)0;
     envelope_from=expand_string("$sender_address");
@@ -2515,27 +2973,32 @@ while (*filter->pc)
     for (;;)
       {
       if (parse_white(filter)==-1) return -1;
-      if (parse_identifier(filter,CUS ":method")==1)
+      if (parse_identifier(filter,CUS ":from")==1)
         {
         if (parse_white(filter)==-1) return -1;
-        if ((m=parse_string(filter,&method))!=1)
+        if ((m=parse_string(filter,&from))!=1)
           {
-          if (m==0) filter->errmsg=CUS "method string expected";
+          if (m==0) filter->errmsg=CUS "from string expected";
           return -1;
           }
-        if (method.length>7 && strncmp(method.character,"mailto:",7)==0)
-          {
-          if (parse_mailto_uri(filter,method.character+7,&recipient,&body)==-1) return -1;
-          }
         }
-      else if (parse_identifier(filter,CUS ":priority")==1)
+      else if (parse_identifier(filter,CUS ":importance")==1)
         {
         if (parse_white(filter)==-1) return -1;
-        if ((m=parse_string(filter,&priority))!=1)
+        if ((m=parse_string(filter,&importance))!=1)
           {
-          if (m==0) filter->errmsg=CUS "priority string expected";
+          if (m==0) filter->errmsg=CUS "importance string expected";
           return -1;
           }
+        if (importance.length!=1 || importance.character[0]<'1' || importance.character[0]>'3')
+          {
+          filter->errmsg=CUS "invalid importance";
+          return -1;
+          }
+        }
+      else if (parse_identifier(filter,CUS ":options")==1)
+        {
+        if (parse_white(filter)==-1) return -1;
         }
       else if (parse_identifier(filter,CUS ":message")==1)
         {
@@ -2548,23 +3011,32 @@ while (*filter->pc)
         }
       else break;
       }
-    if (parse_semicolon(filter)==-1) return -1;
-
-    if (method.length==-1)
+    if (parse_white(filter)==-1) return -1;
+    if ((m=parse_string(filter,&method))!=1)
       {
-        if ((filter_test != FTEST_NONE && debug_selector != 0) || (debug_selector & D_filter) != 0)
-          {
-          debug_printf("Ignoring method-less notification.\n");
-          }
+      if (m==0) filter->errmsg=CUS "missing method string";
+      return -1;
       }
-    else
+    if (parse_semicolon(filter)==-1) return -1;
+    if (parse_mailto_uri(filter,method.character,&recipient,&header,&subject,&body)!=1)
+      return -1;
+    if (message.length==-1) message=subject;
+    if (message.length==-1) expand_header(&message,&str_subject);
+    expand_header(&auto_submitted_value,&str_auto_submitted);
+    auto_submitted_def=expand_string(string_sprintf("${if def:header_auto-submitted {true}{false}}"));
+    if (auto_submitted_value.character == NULL || auto_submitted_def == NULL)
+      {
+      filter->errmsg=CUS "header string expansion failed";
+      return -1;
+      }
+    if (Ustrcmp(auto_submitted_def,"true")!=0 || Ustrcmp(auto_submitted_value.character,"no")==0)
       {
       for (already=filter->notified; already; already=already->next)
         {
         if (already->method.length==method.length
             && (method.length==-1 || strcmp(already->method.character,method.character)==0)
-            && already->priority.length==priority.length
-            && (priority.length==-1 || strcmp(already->priority.character,priority.character)==0)
+            && already->importance.length==importance.length
+            && (importance.length==-1 || strcmp(already->importance.character,importance.character)==0)
             && already->message.length==message.length
             && (message.length==-1 || strcmp(already->message.character,message.character)==0))
           break;
@@ -2575,16 +3047,16 @@ while (*filter->pc)
         struct Notification *sent;
         sent=store_get(sizeof(struct Notification));
         sent->method=method;
-        sent->priority=priority;
+        sent->importance=importance;
         sent->message=message;
         sent->next=filter->notified;
         filter->notified=sent;
         if ((filter_test != FTEST_NONE && debug_selector != 0) || (debug_selector & D_filter) != 0)
           {
-          debug_printf("Notification to `%s'.\n",method.character);
+          debug_printf("Notification to `%s': '%s'.\n",method.character,message.length!=-1 ? message.character : CUS "");
           }
 #ifndef COMPILE_SYNTAX_CHECKER
-        if (exec)
+        if (exec && filter_test == FTEST_NONE)
           {
           string_item *p;
           header_line *h;
@@ -2593,13 +3065,25 @@ while (*filter->pc)
           if ((pid = child_open_exim2(&fd,envelope_to,envelope_to))>=1)
             {
             FILE *f;
+            uschar *buffer;
+            int buffer_capacity;
 
             f = fdopen(fd, "wb");
-            fprintf(f,"From: %s\n",envelope_to);
-            for (p=recipient; p; p=p->next) fprintf(f,"To: %s\n",p->text);
             for (h = header_list; h != NULL; h = h->next)
               if (h->type == htype_received) fprintf(f,"%s",h->text);
-            fprintf(f,"Subject: %s\n",message.length==-1 ? CUS "notification" : message.character);
+            fprintf(f,"From: %s\n",from.length==-1 ? envelope_to : from.character);
+            for (p=recipient; p; p=p->next) fprintf(f,"To: %s\n",p->text);
+            fprintf(f,"Auto-submitted: sieve-notify\n");
+            if (header.length>0) fprintf(f,"%s",header.character);
+            if (message.length==-1)
+              {
+              message.character=US"Notification";
+              message.length=Ustrlen(message.character);
+              }
+            /* Allocation is larger than neccessary, but enough even for split MIME words */
+            buffer_capacity=32+4*message.length;
+            buffer=store_get(buffer_capacity);
+            if (message.length!=-1) fprintf(f,"Subject: %s\n",parse_quote_2047(message.character, message.length, US"utf-8", buffer, buffer_capacity, TRUE));
             fprintf(f,"\n");
             if (body.length>0) fprintf(f,"%s\n",body.character);
             fflush(f);
@@ -2617,6 +3101,13 @@ while (*filter->pc)
           }
         }
       }
+    else
+      {
+      if ((filter_test != FTEST_NONE && debug_selector != 0) || (debug_selector & D_filter) != 0)
+        {
+        debug_printf("Ignoring notification, triggering message contains Auto-submitted: field.\n");
+        }
+      }
     }
 #endif
 #ifdef VACATION
@@ -2687,31 +3178,14 @@ while (*filter->pc)
         }
       else if (parse_identifier(filter,CUS ":from")==1)
         {
-        int start, end, domain;
-        uschar *error,*ss;
-
         if (parse_white(filter)==-1) return -1;
         if ((m=parse_string(filter,&from))!=1)
           {
           if (m==0) filter->errmsg=CUS "from string expected";
           return -1;
           }
-        if (from.length>0)
-          {
-          ss = parse_extract_address(from.character, &error, &start, &end, &domain,
-            FALSE);
-          if (ss == NULL)
-            {
-            filter->errmsg=string_sprintf("malformed address \"%s\" in "
-              "Sieve filter: %s", from.character, error);
-            return -1;
-            }
-          }
-        else
-          {
-          filter->errmsg=CUS "empty :from address in Sieve filter";
+        if (check_mail_address(filter,&from)!=1)
           return -1;
-          }
         }
       else if (parse_identifier(filter,CUS ":addresses")==1)
         {
@@ -2886,7 +3360,7 @@ while (*filter->pc)
             }
           else
             {
-            struct String qp;
+            struct String qp = { NULL, 0 };  /* Keep compiler happy (PH) */
 
             capacity = 0;
             start = reason.length;
@@ -2933,11 +3407,14 @@ filter->line=1;
 filter->keep=1;
 filter->require_envelope=0;
 filter->require_fileinto=0;
+#ifdef ENCODED_CHARACTER
+filter->require_encoded_character=0;
+#endif
 #ifdef ENVELOPE_AUTH
 filter->require_envelope_auth=0;
 #endif
-#ifdef NOTIFY
-filter->require_notify=0;
+#ifdef ENOTIFY
+filter->require_enotify=0;
 filter->notified=(struct Notification*)0;
 #endif
 #ifdef SUBADDRESS
@@ -3005,11 +3482,14 @@ while (parse_identifier(filter,CUS "require"))
     {
     if (eq_octet(check,&str_envelope,0)) filter->require_envelope=1;
     else if (eq_octet(check,&str_fileinto,0)) filter->require_fileinto=1;
+#ifdef ENCODED_CHARACTER
+    else if (eq_octet(check,&str_encoded_character,0)) filter->require_encoded_character=1;
+#endif
 #ifdef ENVELOPE_AUTH
     else if (eq_octet(check,&str_envelope_auth,0)) filter->require_envelope_auth=1;
 #endif
-#ifdef NOTIFY
-    else if (eq_octet(check,&str_notify,0)) filter->require_notify=1;
+#ifdef ENOTIFY
+    else if (eq_octet(check,&str_enotify,0)) filter->require_enotify=1;
 #endif
 #ifdef SUBADDRESS
     else if (eq_octet(check,&str_subaddress,0)) filter->require_subaddress=1;
