@@ -1,4 +1,4 @@
-/* $Cambridge: exim/exim-src/src/spf.c,v 1.6 2005/06/27 15:28:45 tom Exp $ */
+/* $Cambridge: exim/exim-src/src/spf.c,v 1.7 2007/05/17 19:55:10 tom Exp $ */
 
 /*************************************************
 *     Exim - an Internet mail transport agent    *
@@ -43,6 +43,12 @@ int spf_init(uschar *spf_helo_domain, uschar *spf_remote_addr) {
     return 0;
   }
 
+  if (SPF_server_set_rec_dom(spf_server, primary_hostname)) {
+    debug_printf("spf: SPF_server_set_rec_dom() failed.\n");
+    spf_server = NULL;
+    return 0;
+  }
+
   spf_request = SPF_request_new(spf_server);
 
   if (SPF_request_set_ipv4_str(spf_request, spf_remote_addr)) {
