@@ -1,4 +1,4 @@
-/* $Cambridge: exim/exim-src/src/srs.h,v 1.2 2004/12/16 15:11:47 tom Exp $ */
+/* $Cambridge: exim/exim-src/src/srs.h,v 1.3 2005/06/27 15:11:04 tom Exp $ */
 
 /*************************************************
 *     Exim - an Internet mail transport agent    *
@@ -21,7 +21,7 @@ int eximsrs_init();
 int eximsrs_done();
 int eximsrs_forward(uschar **result, uschar *orig_sender, uschar *domain);
 int eximsrs_reverse(uschar **result, uschar *address);
-int eximsrs_db(BOOL reverse, uschar *srs_db);
+int eximsrs_db_set(BOOL reverse, uschar *srs_db);
 
 srs_result eximsrs_db_insert(srs_t *srs, char *data, uint data_len, char *result, uint result_len);
 srs_result eximsrs_db_lookup(srs_t *srs, char *data, uint data_len, char *result, uint result_len);
